==> sqla_ext-0.0.0.tar.gz: sqla_ext-0.0.0/README.md <==
# sqla

<p>

<a href="https://github.com/olirice/sqla_ext/actions"><img src="https://github.com/olirice/sqla_ext/workflows/Tests/badge.svg" alt="Tests" height="18"></a>
<a href="https://sqla_ext.readthedocs.io/en/latest/?badge=latest"><img src="https://readthedocs.org/projects/sqla_ext/badge/?version=latest" alt="Tests" height="18"></a>
<a href="https://codecov.io/gh/olirice/sqla_ext"><img src="https://codecov.io/gh/olirice/sqla_ext/branch/master/graph/badge.svg" height="18"></a>
<a href="https://github.com/psf/black">
        <img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Codestyle Black" height="18">
    </a>
</p>

<p>
    <a href="https://www.python.org/downloads/"><img src="https://img.shields.io/badge/python-3.6+-blue.svg" alt="Python version" height="18"></a>
  <a href="https://badge.fury.io/py/sqla_ext"><img src="https://badge.fury.io/py/sqla_ext.svg" alt="PyPI version" height="18"></a>
    <a href="https://github.com/olirice/sqla_ext/blob/master/LICENSE"><img src="https://img.shields.io/pypi/l/markdown-subtemplate.svg" alt="License" height="18"></a>
    <a href="https://pypi.org/project/sqla_ext/"><img src="https://img.shields.io/pypi/dm/sqla_ext.svg" alt="Download count" height="18"></a>
</p>

---

**Documentation**: <a href="https://sqla_ext.readthedocs.io/en/latest/" target="_blank">https://sqla_ext.readthedocs.io/en/latest/</a>

**Source Code**: <a href="https://github.com/olirice/sqla_ext" target="_blank">https://github.com/olirice/sqla_ext</a>

---

# {{ PROJECT }}

==> sqla_ext-0.0.1.tar.gz: sqla_ext-0.0.1/README.md <==
# sqla_ext

<p>

<a href="https://github.com/olirice/sqla_ext/actions"><img src="https://github.com/olirice/sqla_ext/workflows/tests/badge.svg" alt="Tests" height="18"></a>
<a href="https://sqla_ext.readthedocs.io/en/latest/?badge=latest"><img src="https://readthedocs.org/projects/sqla_ext/badge/?version=latest" alt="Tests" height="18"></a>
<a href="https://codecov.io/gh/olirice/sqla_ext"><img src="https://codecov.io/gh/olirice/sqla_ext/branch/master/graph/badge.svg" height="18"></a>
<a href="https://github.com/psf/black">
        <img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Codestyle Black" height="18">
    </a>
</p>

<p>
    <a href="https://www.python.org/downloads/"><img src="https://img.shields.io/badge/python-3.6+-blue.svg" alt="Python version" height="18"></a>
  <a href="https://badge.fury.io/py/sqla_ext"><img src="https://badge.fury.io/py/sqla_ext.svg" alt="PyPI version" height="18"></a>
    <a href="https://github.com/olirice/sqla_ext/blob/master/LICENSE"><img src="https://img.shields.io/pypi/l/markdown-subtemplate.svg" alt="License" height="18"></a>
    <a href="https://pypi.org/project/sqla_ext/"><img src="https://img.shields.io/pypi/dm/sqla_ext.svg" alt="Download count" height="18"></a>
</p>

---

**Documentation**: <a href="https://sqla_ext.readthedocs.io/en/latest/" target="_blank">https://sqla_ext.readthedocs.io/en/latest/</a>

**Source Code**: <a href="https://github.com/olirice/sqla_ext" target="_blank">https://github.com/olirice/sqla_ext</a>

---

SQLAlchemy extension.
